import { prisma } from "../configs/prismaClient.js";

class UsuarioRepository {
    static async findAll(filtros, page=1, limit=10) {

        page = Math.max(page, 1);
        limit = Math.max(limit, 1);

        const skip = (page - 1) * limit;
        const take = limit;

        const data = await prisma.usuario.findMany({
            skip,
            take,
            where: filtros
        });

        const totalCount = await prisma.usuario.count();
        const totalPages = Math.ceil(totalCount / limit);

        return {
            data,
            totalCount,
            totalPages,
            currentPage: page,
        };
    }

    static async findById(id) {
        return await prisma.usuario.findUnique({ where: { id: id } });
    }

    static async findByEmail(email) {
        return await prisma.usuario.findUnique({ where: { email: email } });
    }

    static async create(data) {
        return await prisma.usuario.create({ data: data });
    }

    static async update(id, data) {
        return await prisma.usuario.update({ where: { id: id }, data: data });
    }

    static async delete(id) {
        return await prisma.usuario.delete({ where: { id: id } });
    }
}

export default UsuarioRepository;
