import LoginSchema from '../schema/loginSchema.js';
import UsuarioRepository from '../repository/usuarioRepository.js';
import Jwt from 'jsonwebtoken';
import Hash from '../utils/hash.js';

class AutenticacaoServices {
    static async login(data){
        // valida os campos siape e senha estão dentro do padrão
        const loginValidated = LoginSchema.loginSchema.parse(data);
        //realiza a busca do usuario pelo seu numero de siape
        const usuario = await UsuarioRepository.findAll({siape: loginValidated.siape});
        //verifica se retornou o usuario
        if(usuario.data.length==0){
            throw{
                message:'Usuario não encontrado!',
                code:400
            };
        }
        
        //verifica se o usuario esta ativo
        if(usuario.data[0].ativo == false){
            throw{
                message:'Usuario inativo!',
                code:400
            };
        }
        //comparar o hash
        const ValidatedHash = await Hash.compararSenha(data.senha,usuario.data[0].senha);
        if(ValidatedHash == false){
            throw{
                message:'Senha invalida!',
                code:400
            };
        }
        // criando o token 
        const token = Jwt.sign(usuario.data[0], process.env.JWT_SECRET, { expiresIn: '30d' });
        return token;
    }
}

export default AutenticacaoServices;
