'use client';

import fetchApi from "@/services/fetApi";
import { useQuery } from "@tanstack/react-query";

export default function Docente(){

  const { isPending, error, data} = useQuery({
		queryKey: ["getSalas"],
		queryFn: async () => {
			const response = await fetchApi("http://localhost:7002/usuario", "GET");

			if (response.error) {
        error(response.message);
				throw response.message;
			} else {
				return response.data;
			}
		},
	});


  return (
    <div className="p-16">
      <h1 className="font-sans text-blue-800 text-4xl mb-36">Gerenciamento de Docentes</h1>
      {isPending ? (
        <div className="w-12 h-12 border-4 border-t-4 border-gray-300 rounded-full animate-spin border-t-blue-500"></div>
      ) : error ? (
        <div className="text-center py-4 text-red-600">
          Ocorreu um erro: {error.message}
        </div>
      ) : (
        <div className="overflow-x-auto">
          <table className="table-auto border-collapse border border-gray-300 w-full">
            <thead>
              <tr className="bg-gray-100">
                <th className="border border-gray-300 px-4 py-2">Foto</th>
                <th className="border border-gray-300 px-4 py-2">Nome</th>
                <th className="border border-gray-300 px-4 py-2">Email</th>
                <th className="border border-gray-300 px-4 py-2">Dape</th>
              </tr>
            </thead>
            <tbody>
              {data.map((usuario) => (
                <tr key={usuario.siape} className="hover:bg-gray-50">
                  <td className="border border-gray-300 px-4 py-2 text-center">
                    <img
                      src={usuario.foto}
                      alt={`Foto de ${usuario.nome}`}
                      className="w-12 h-12 rounded-full mx-auto"
                    />
                  </td>
                  <td className="border border-gray-300 px-4 py-2">{usuario.nome}</td>
                  <td className="border border-gray-300 px-4 py-2">{usuario.email}</td>
                  <td className="border border-gray-300 px-4 py-2 text-center">
                    {usuario.dape ? "Sim" : "Não"}
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      )}
    </div>
  );
}