'use client';

import CardFiltrosReservas from "@/components/CardFiltrosReservas";
import fetchApi from "@/services/fetApi";
import { useQuery } from "@tanstack/react-query";
import { useEffect, useState } from "react";
import { format } from "date-fns";
import Calendario from "@/components/Calendario";
import ModalEnsalamento from "@/components/ModalEnsalamento";

export default function Home() {
  const urlRservas = "http://localhost:7002/reserva";
  const urlSalas = "http://localhost:7002/sala";

  // querys para filtrar as reservas
  const [querys, setQuerys] = useState({
    id_sala: 1,
    id_usuario: null,
    turma: "",
    dia: new Date(),
  });

  const { isPending, error, data } = useQuery({
    queryKey: ["getReservas", querys],
    queryFn: async () => {
      console.log('querys', querys);
      const queryString = Object.entries(querys)
        .filter(([_, value]) => value) // Ignora campos vazios
        .map(([key, value]) => {
          if (key === "dia") {
            const formattedDate = format(new Date(value), "dd-MM-yyyy"); // Formata para dd-MM-yyyy
            return `${key}=${formattedDate}`;
          }
          return `${key}=${value}`
        })
        .join("&");

      const response = await fetchApi(`${urlRservas}?${queryString}&limit=30`, "GET"); //definido como 30 porque é o maximo de reserva por semana

      if (response.error) {
        error(response.message);
        throw response.message;
      } else {
        return response.data;
      }
    },
  });

  const { isPending: isPendingSala, error: erroSala, data: dataSala } = useQuery({
    queryKey: ["getBlocos"],
    queryFn: async () => {
      const response = await fetchApi(`${urlSalas}?limit=99`, "GET");

      if (response.error) {
        error(response.message);
        throw response.message;
      } else {
        // Remove duplicatas com base no nome da sala
        const uniqueSalas = [...new Map(response.data.map((item) => [item.bloco, item])).values()];
        return uniqueSalas;
      }
    },
  });


  return (
    <main className="w-full h-screen">
      <CardFiltrosReservas listaBlocos={dataSala ? dataSala.map(sala => sala.bloco) : []} onChange={(updatedFilters) => { console.log('atualizo'); setQuerys((prev) => ({ ...prev, ...updatedFilters })) }} />
      {isPending ? (
        <div className="w-12 h-12 border-4 border-t-4 border-gray-300 rounded-full animate-spin border-t-blue-500"></div>
      ) : error ? (
        <div className="text-center py-4 text-red-600">
          Ocorreu um erro: {error.message}
        </div>
      ) : <>
        <Calendario reservas={data} diaAtual={querys.dia} />
      </>}
    </main>
  );
}
