import CardDiaCalendario from "./CardDiaCalendario";
import React, { useState } from "react";
import CardReserva from "./CardReserva";
import { get } from "react-hook-form";

const cores = [
  "rgba(255, 99, 132, 0.6)", // Rosa claro com transparência
  "rgba(54, 162, 235, 0.6)", // Azul claro com transparência
  "rgba(75, 192, 192, 0.6)", // Verde claro com transparência
  "rgba(255, 206, 86, 0.2)", // Amarelo claro com transparência
  "rgba(153, 102, 255, 0.6)", // Roxo claro com transparência
];

let ultimaCorUsada = null;
const obterCorAleatoria = () => {
  let cor;
  do {
    cor = cores[Math.floor(Math.random() * cores.length)];
  } while (cor === ultimaCorUsada);
  ultimaCorUsada = cor;
  return cor;
};

export default function Calendario({ reservas, diaAtual }) {
  const diasSemana = [];
  const semanas = ['Dom', 'Seg', 'Ter', 'Qua', 'Qui', 'Sex', 'Sáb'];

  // Obter o índice do dia da semana do dia atual
  const diaAtualSemanaIndex = diaAtual.getDay();

  // Função para ajustar a data
  const ajustarData = (baseDate, offset) => {
    const novaData = new Date(baseDate);
    novaData.setDate(baseDate.getDate() + offset); // Ajusta o dia com o offset
    return novaData;
  };

  // Gerar os dias da semana com as datas ajustadas
  for (let i = 0; i < 7; i++) {
    const offset = i - diaAtualSemanaIndex; // Calcula o deslocamento em relação ao dia atual
    const diaAjustado = ajustarData(diaAtual, offset);
    diasSemana.push({
      dia: semanas[i], // Nome do dia da semana
      data: diaAjustado, // Data ajustada
    });
  }
  diasSemana.shift() // Remove o domingo

  const horasDoDia = Array.from({ length: 17 }, (_, i) => `${i + 7}:00`); // 07:00 até 23:00

  // Função para formatar a data e extrair o dia da semana
  const obterDiaSemana = (dataISO) => {
    const data = new Date(dataISO);
    return data.getDay(); // 0 = Domingo, 1 = Segunda, ..., 6 = Sábado
  };


  return (
    <div className="">

      {/* Cabeçalho do dia */}
      <div className="grid grid-cols-6 flex-1 pl-16 bg-gray-200 shadow-md">
        {diasSemana.map((dia, index) => {
          const diaAtualFormatado = diaAtual.toLocaleDateString('pt-BR', {day: 'numeric'});
          const diaFormatado = dia.data.toLocaleDateString('pt-BR', {day: 'numeric'});
          return (
            <div key={index} className={`h-20 ${diaAtualFormatado == diaFormatado? 'text-cor' : 'bg-gray-200'} border-2 flex items-center justify-center flex-col font-bold text-2xl`}>
              <p>{dia.dia}</p>
              <p>{diaFormatado}</p>
            </div>
          )
        })}
      </div>

      {/* Corpo do calendário */}
      <div className="flex overflow-auto h-full">
        {/* Coluna de horas */}
        <div className="w-16 flex flex-col border-r h-[1730px]">
          {horasDoDia.map((hora, idx) => (
            <div
              key={idx}
              className="h-[102px] flex-shrink-0 flex items-center justify-center text-gray-600 border-b border-gray-600 relative"
            >
              <span className="bg-white block pl-2 absolute top-[-12px]">
                {hora === "7:00" ? "" : `${parseInt(hora.split(":")[0], 10)} ${parseInt(hora.split(":")[0], 10) < 12 ? "AM" : "PM"}`}
              </span>

            </div>
          ))}
        </div>

        {/* Colunas dos dias da semana */}
        <div className="grid grid-cols-6 flex-1 border-1 h-[1730px]">
          {diasSemana.map((dia, diaIndex) => {
            const diaAtualFormatado = diaAtual.toLocaleDateString('pt-BR', {day: 'numeric'});
            const diaFormatado = dia.data.toLocaleDateString('pt-BR', {day: 'numeric'});
            return(
              <div key={diaIndex} className={`border-r border-gray-600 ${diaFormatado == diaAtualFormatado? 'bg-fundoDiaAtual' : ''}`}>
              {/* Linhas de horas */}
              {horasDoDia.map((hora, idx) => (
                <div
                  key={idx}
                  className="h-[102px] border-b border-gray-600 flex items-center justify-center text-gray-300"
                >
                  {/* Apenas uma linha visual, o conteúdo é opcional */}
                  
                </div>
              ))}
              {/* Corpo com as reservas */}
              <div className="relative">
                {reservas
                  .filter(
                    (reserva) =>
                      obterDiaSemana(reserva.hora_inicio) === diaIndex + 1 // Filtro para o dia correto (segunda = 1)
                  )
                  .map((reserva, index) => {
                    const horaInicio = new Date(reserva.hora_inicio);
                    const horaFim = new Date(reserva.hora_fim);
                    const diferencaHoras = (horaFim - horaInicio) / (1000 * 60 * 60); // Duração em horas

                    // Calcula a posição superior
                    const alturaHora = 102; // Altura de cada hora no CSS
                    const posicaoTop = (
                      ((horaInicio.getHours() - 7) * alturaHora) + // Ajusta para começar às 07:00
                      ((horaInicio.getMinutes() / 60) * alturaHora) - 1428
                    );

                    // Define a altura
                    const altura = diferencaHoras < 1
                      ? 85 // Altura mínima para reservas com menos de 1 hora
                      : 170 // Altura dobrada para reservas com 1 hora ou mais

                    return (
                      <CardReserva
                        key={index}
                        reserva={reserva}
                        posicaoTop={posicaoTop}
                        altura={altura}
                        cor={obterCorAleatoria()}
                      />
                    );
                  })}
              </div>
            </div>
            )
          })}
        </div>
      </div>
    </div>
  );
}
