'use client'

import { get, useForm } from "react-hook-form"
import { Calendar } from "@/components/ui/calendar"
import { Button } from "@/components/ui/button"
import { CalendarIcon, Watch } from "lucide-react"
import { cn } from "@/lib/utils"
import { format } from "date-fns";
import { ptBR } from "date-fns/locale";
import { useState } from "react"

import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover"
import {
  Form,
  FormControl,
  FormDescription,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form"
import InputSelect from "./Select"
import { useQuery } from "@tanstack/react-query"
import fetchApi from "@/services/fetApi"
import ReservaDialog from "@/components/Dialog";
import ModalEnsalamento from "./ModalEnsalamento"

export default function CardFiltrosReservas({ onChange, listaBlocos }) {
  const urlSalas = "http://localhost:7002/sala?limit=97";
  const [modal,setModal] = useState(false);
  const form = useForm({
    defaultValues: {
      bloco: "A",
      sala: 1,
      modo: "Por sala",
      data: new Date(),
    },
  });

  const onSubmit = (data) => {
    onChange({
      bloco: data.bloco,
      id_sala: data.sala,
      modo: data.modo,
      dia: data.data,
    });
  };

  const { isPending, error, data } = useQuery({
    queryKey: ["getSalas", form.getValues('bloco')],
    queryFn: async () => {
      const response = await fetchApi(`${urlSalas}&bloco=${form.getValues('bloco')}`, "GET");
      if (response.error) {
        error(response.message);
        throw response.message;
      } else {
        // Remove duplicatas com base no nome da sala
        const uniqueSalas = [...new Map(response.data.map((item) => [item.id, item])).values()]
        return uniqueSalas;
      }
    },
  });

  return (
    <div className="max-h-[186px] flex justify-between bg-cinzaClaro w-full p-[24px]">{/* shadow-md shadow-y-4*/}
      <Form {...form}>
        <form className="flex flex-wrap gap-4 w-fit" onChange={form.handleSubmit(onSubmit)}>
          {/* Select para o modo de exibição */}
          <InputSelect
            name="modo"
            titulo='Modo de exibição de reservas'
            placeholder="Por sala"
            options={["Por sala", "Apenas minhas reservas"].map((modo) => ({ id: modo, nome: modo }))}
            control={form.control}
            w="w-[270px]"
          />

          {/* Select para o bloco */}
          <InputSelect
            name="bloco"
            titulo='Bloco'
            placeholder="Selecione um Bloco"
            options={listaBlocos.map((bloco) => ({ id: bloco, nome: bloco }))}
            onChange={() => {
              // Reseta o valor do campo sala
              onChange({ sala: null });
              form.handleSubmit(onSubmit)();  // Dispara o onSubmit para atualizar o estado
            }}
            control={form.control}
            w="w-[80px]"
          />

          {/* Select para a sala */}
          <InputSelect
            name="sala"
            titulo="Sala"
            placeholder={`${data ? data[data.findIndex((sala) => sala.id == form.getValues('sala'))]?.nome ? data[data.findIndex((sala) => sala.id == form.getValues('sala'))]?.nome : 'Selecione uma sala' : 'Selecione uma sala'}`} // gambiarra para pegar o nome da sala
            options={data ? data.map((sala) => ({ id: sala.id, nome: sala.nome })) : []}
            control={form.control}
            w="w-[180px]"
          />

          {/* Calendário */}

          <FormField
            control={form.control}
            name="data"
            render={({ field }) => (
              <FormItem className="flex flex-col">
                <FormLabel className=''>Data</FormLabel>
                <Popover>
                  <PopoverTrigger asChild>
                    <FormControl>
                      <Button
                        variant={"outline"}
                        className={cn(
                          "w-[240px] pl-3 text-left font-normal",
                          !field.value && "text-muted-foreground"
                        )}
                      >
                        {field.value ? (
                          format(field.value, "dd 'de' MMMM 'de' yyyy", { locale: ptBR })
                        ) : (
                          <span>Selecione uma data</span>
                        )}
                        <CalendarIcon className="ml-auto h-4 w-4 opacity-50" />
                      </Button>
                    </FormControl>
                  </PopoverTrigger>
                  <PopoverContent className="w-auto p-0" align="start">
                    <Calendar
                      mode="single"
                      selected={field.value}
                      onSelect={(date) => {
                        field.onChange(date); // Atualiza o valor do campo com a data
                        form.handleSubmit(onSubmit)(); // Submete o formulário
                      }}

                    />
                  </PopoverContent>
                </Popover>
                <FormMessage />
              </FormItem>
            )}
          />
        </form>
      </Form>
      <ReservaDialog />
      <ModalEnsalamento />
    </div>
  )
}
