import fetchApi from "@/services/fetApi";
import { useQuery } from "@tanstack/react-query";

export default function CardReserva({ reserva, posicaoTop, altura, cor }) {
  // Função para converter o horário em formato ISO para "HH:MM"
  const obterHora = (dataISO) => {
    const data = new Date(dataISO);
    return `${data.getUTCHours()}:${String(data.getUTCMinutes()).padStart(2, "0")}`;
  };

  const urlUser = "http://localhost:7002/usuario";
  const { isPending, error, data } = useQuery({
    queryKey: ["getUser", reserva],
    queryFn: async () => {
      const response = await fetchApi(`${urlUser}?id=${reserva.id_usuario}`, "GET");
      if (response.error) {
        throw response.message;
      } else {
        return response.data;
      }
    },
  });



  //adiciona animlção com tempo aleátorio na exibição dos cards reservas
  const animacoes = [
    'animate-scaleIn',
    'animate-scaleIn2',
    'animate-scaleIn3',
    'animate-scaleIn4',
  ]

  const animcaoSelecionada = animacoes[Math.floor(Math.random() * animacoes.length)];

  // Criar objetos Date para hora_inicio e hora_fim
  const horaInicio = new Date(reserva.hora_inicio);
  const horaFim = new Date(reserva.hora_fim);

  // Calcular a diferença em milissegundos
  const diferencaMs = horaFim - horaInicio;

  // Converter a diferença para minutos
  const minutosReserva = diferencaMs / (1000 * 60);


  return (
    <div
      className={`${'animate-scaleIn'} h-20 absolute text-gray-100 ${minutosReserva > 51? 'p-4' : 'pt-2 pb pl-4'} rounded-md shadow-md border-secondary hover:scale-105 transition-transform duration-500 ease-in-out mb-2${isPending
        ? "bg-gray-300"
        : error
          ? "bg-red-500"
          : "bg-secondary/80"
        }`}
      style={{
        top: `${posicaoTop}px`,
        height: `${altura}px`,
        left: "4px",
        right: "4px",
        background: "linear-gradient(to bottom, rgba(90, 108, 115, 0.7), rgba(90, 108, 115, 0.9))",
        transition: " 0.2s cubic-bezier(0.25, 1, 0.5, 1)", // Suave e não linear
      }}
      onMouseEnter={(e) =>
        (e.currentTarget.style.background = "linear-gradient(to bottom, #5A6C73, #3c6C73)")
      }
      onMouseLeave={(e) =>
        (e.currentTarget.style.background = "linear-gradient(to bottom, rgba(90, 108, 115, 0.7), rgba(90, 108, 115, 0.9))")
      }
      aria-label={`Reserva de ${reserva.turma} das ${obterHora(
        reserva.hora_inicio
      )} às ${obterHora(reserva.hora_fim)}`}
      title={`Turma: ${reserva.turma}\nDescrição: ${reserva.descricao}\nHorário: ${obterHora(
        reserva.hora_inicio
      )} - ${obterHora(reserva.hora_fim)}`}
    >
      {isPending ? (
        <div className="flex items-center justify-center h-full">
          <span className="loader border-t-2 border-white border-solid rounded-full w-4 h-4"></span>
        </div>
      ) : error ? (
        <div className="text-red-500 text-sm">
          Erro ao carregar informações do professor.
        </div>
      ) : (<>
        <div className="font-bold text-md mt-1 text-cor">
          {obterHora(reserva.hora_inicio)} - {obterHora(reserva.hora_fim)}
        </div>
        <div className="text-sm">
          <span className="font-bold">Prof:</span> {data[0]?.nome || "Desconhecido"}
        </div>
        <div className="text-sm">
              <span>Turma: </span> {reserva.turma}
            </div>
        {minutosReserva > 51 ? (
          <>
            <div className="text-sm mt-1 text-gray-200">{reserva.descricao}</div>
            <div className="text-sm">
              <span>Descrição: </span> {reserva.descricao}
            </div>
          </>
        ) : ''}
      </>)}
    </div>
  );
}
