import {
    Dialog,
    DialogClose,
    DialogContent,
    DialogDescription,
    DialogFooter,
    DialogHeader,
    DialogTitle,
    DialogTrigger,
} from "@/components/ui/dialog";
import React, { useEffect, useRef, useState } from "react";
import { z } from "zod";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Form, FormField, FormItem, FormLabel, FormMessage, FormControl } from "@/components/ui/form";
import { format } from "date-fns";
import { Calendar as CalendarIcon, Clock } from "lucide-react";
import { cn } from "@/lib/utils";
import { Calendar } from "@/components/ui/calendar";
import {
    Popover,
    PopoverContent,
    PopoverTrigger,
} from "@/components/ui/popover";
import { ptBR } from "date-fns/locale";
import { Label } from "@radix-ui/react-label";
import { TimePickerInput } from "./time-picker-input";

const formSchema = z.object({
    sala: z.string(),
    turma: z.string(),
    descricao: z.string(),
    data: z.date(),
});

export default function ReservaDialog() {
    const [initialHour, setInitialHour] = useState(new Date());
    const [finalHour, setFinalHour] = useState(new Date());
    const [initialMinute, setInitialMinute] = useState(new Date());
    const [finalMinute, setFinalMinute] = useState(new Date());
    const initialMinuteRef = useRef(null);
    const initialHourRef = useRef(null);
    const finalMinuteRef = useRef(null);
    const finalHourRef = useRef(null);

    const formRef = useRef(null); // Reference to the form

    const form = useForm({
        resolver: zodResolver(formSchema),
        defaultValues: {
            sala: "",
            turma: "",
            descricao: "",
            data: new Date(),
            horaInicial: new Date().getHours(),
            horaFinal: new Date().getMinutes(),
            minutoInicial: new Date().getHours(),
            minutoFinal: new Date().getMinutes(),
        },
    });

    function formatTimeRange(initialHour, initialMinute, finalHour, finalMinute, dateString) {
        // Convert the received date string to a Date object
        const date = new Date(dateString);

        // Get the time zone offset in minutes and convert it to hours and minutes
        const offsetInMinutes = date.getTimezoneOffset();
        const offsetInHours = offsetInMinutes / 60;

        // Extract year, month, and day from the Date object
        const year = date.getFullYear();
        const month = date.getMonth(); // getMonth() returns 0 for January, 11 for December
        const day = date.getDate();

        // Adjust the start and end times by applying the timezone offset
        const startDate = new Date(year, month, day, initialHour - offsetInHours, initialMinute);
        const endDate = new Date(year, month, day, finalHour - offsetInHours, finalMinute);

        // Format both start and end times to ISO string with 'Z' indicating UTC
        const formattedStartTime = startDate.toISOString();
        const formattedEndTime = endDate.toISOString();

        return {
            hora_inicio: formattedStartTime,
            hora_fim: formattedEndTime
        };
    }

    // Função de submissão dos dados (após tudo estar validado)
    const onSubmit = async () => {
        const dataJson = formatTimeRange(initialHour, initialMinute, finalHour, finalMinute, form.getValues("data"));
        const object = {
            id_sala: 5,
            id_usuario: 4,
            turma: form.getValues("turma"),
            ...dataJson,
            descricao: form.getValues("descricao"),
            id_reservante: 3
        }
        const token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6Niwibm9tZSI6IkJlYXRyaXogU2FudG9zIiwiZW1haWwiOiJiZWF0cml6QGV4YW1wbGUuY29tIiwic2VuaGEiOiIkMmEkMTAkQlpUOUNOSlo2TmQ3UnpSZC4wNFdwLnd5R2dSQTJuTjdnclRRZ0N2RHlTem9lcHd3LldDQTYiLCJzaWFwZSI6MjQ4NjEzLCJmb3RvIjpudWxsLCJkYXBlIjpmYWxzZSwiYXRpdm8iOnRydWUsImlhdCI6MTczMzE5MDk3OCwiZXhwIjoxNzM1NzgyOTc4fQ.5bfDyE46gcMsdRGQAN1RIgph8elGdl6tMjR4DzIn_2g";
        const response = await fetch("http://localhost:7002/reserva", {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
                "Authorization": `Bearer ${token}`,
            },
            body: JSON.stringify(object),
        });
        console.log(response);
    };

    const handleInitialHourChange = (e) => {
        console.log(e.target.value);
    };

    const handleFinalHourChange = (e) => {
        const hour = parseInt(e.target.value, 10); // Parse to ensure it's a number
        if (!isNaN(hour) && hour >= 0 && hour < 24) {
            const newDate = new Date(form.getValues("horaFinal")).getHours();
            newDate.setHours(hour);
            form.setValue("horaFinal", hour);
            setFinalHour(hour);
        } else {
            console.error("Invalid hour provided:", e.target.value);
        }
    };


    const handleInitialMinuteChange = (e) => {
        const minute = parseInt(e.target.value, 10); // Parse to ensure it's a number
        if (!isNaN(minute) && minute >= 0 && minute < 60) {
            const newDate = new Date(form.getValues("minutoInicial")).getMinutes();
            newDate.setMinutes(minute);
            form.setValue("minutoInicial", minute);
            setInitialMinute(minute);
        } else {
            console.error("Invalid minute provided:", e.target.value);
        }
    };


    const handleFinalMinuteChange = (e) => {
        const minute = parseInt(e.target.value, 10); // Parse to ensure it's a number
        if (!isNaN(minute) && minute >= 0 && minute < 60) {
            const newDate = new Date(form.getValues("minutoFinal")).getMinutes();
            newDate.setMinutes(minute);
            form.setValue("minutoFinal", minute);
            setFinalMinute(minute);
        } else {
            console.error("Invalid minute provided:", e.target.value);
        }
    };

    const handleButtonClick = () => {
        if (formRef.current) {
            formRef.current.requestSubmit(); // Trigger form submission
        }
    };

    return (
        <Dialog>
            <DialogTrigger asChild>
                <Button className="bg-[#89A8B2] self-end text-white hover:bg-[#5A6C73] hover:text-white" variant="outline">Reservar</Button>
            </DialogTrigger>
            <DialogContent className="sm:max-w-md">
                <DialogHeader>
                    <DialogTitle>Criar reserva</DialogTitle>
                    <DialogDescription>
                        Insira os dados corretamente para criar uma nova reserva.
                    </DialogDescription>
                </DialogHeader>
                <Form {...form}>
                    <form
                        ref={formRef}
                        onSubmit={form.handleSubmit(onSubmit)}
                        className="space-y-4">
                        <FormField
                            control={form.control}
                            name="sala"
                            render={({ field }) => (
                                <FormItem>
                                    <FormLabel>Sala</FormLabel>
                                    <FormControl>
                                        <Input placeholder="Ex.: Laboratório 03" {...field} />
                                    </FormControl>
                                    <FormMessage />
                                </FormItem>
                            )}
                        />

                        <FormField
                            control={form.control}
                            name="turma"
                            render={({ field }) => (
                                <FormItem>
                                    <FormLabel>Turma</FormLabel>
                                    <FormControl>
                                        <Input placeholder="Ex.: ADS 2023" {...field} />
                                    </FormControl>
                                    <FormMessage />
                                </FormItem>
                            )}
                        />

                        <FormField
                            control={form.control}
                            name="data"
                            render={({ field }) => (
                                <FormItem className="flex flex-col">
                                    <FormLabel className='mb-[9px]'>Data</FormLabel>
                                    <Popover>
                                        <PopoverTrigger asChild>
                                            <FormControl>
                                                <Button
                                                    variant={"outline"}
                                                    className={cn(
                                                        "w-full pl-3 text-left font-normal",
                                                        !field.value && "text-muted-foreground"
                                                    )}
                                                >
                                                    {field.value ? (
                                                        format(field.value, "dd 'de' MMMM 'de' yyyy", { locale: ptBR })
                                                    ) : (
                                                        <span>Selecione uma data</span>
                                                    )}
                                                    <CalendarIcon className="ml-auto h-4 w-4 opacity-50" />
                                                </Button>
                                            </FormControl>
                                        </PopoverTrigger>
                                        <PopoverContent className="w-auto p-0" align="start">
                                            <Calendar
                                                mode="single"
                                                selected={field.value}
                                                onSelect={(date) => {
                                                    field.onChange(date); // Atualiza o valor do campo com a data
                                                }}
                                            />
                                            <div className="px-4 pb-4">
                                                <div className="flex items-end gap-2">
                                                    <div className="grid gap-1 text-center">
                                                        <Label htmlFor="hours" className="text-xs">
                                                            Hours
                                                        </Label>
                                                        <TimePickerInput
                                                            picker="hours"
                                                            date={form.getValues('horaInicial') || new Date()}
                                                            setDate={(newDate) => {
                                                                const hour = newDate.getHours();
                                                                form.setValue('horaInicial', newDate);
                                                                setInitialHour(hour);
                                                            }}
                                                            ref={initialHourRef}
                                                            onLeftFocus={() => initialHourRef.current?.focus()}
                                                            onChange={handleInitialHourChange}
                                                        />
                                                    </div>
                                                    <div className="grid gap-1 text-center">
                                                        <Label htmlFor="minutes" className="text-xs">
                                                            Minutes
                                                        </Label>
                                                        <TimePickerInput
                                                            picker="minutes"
                                                            date={form.getValues('minutoInicial') || new Date()}
                                                            setDate={(newDate) => {
                                                                const minute = newDate.getMinutes();
                                                                form.setValue('minutoInicial', newDate);
                                                                setInitialMinute(minute); // You can remove setTime since it's not used
                                                            }}
                                                            ref={initialMinuteRef}
                                                            onLeftFocus={() => initialMinuteRef.current?.focus()}
                                                            onChange={handleInitialMinuteChange}
                                                        />
                                                    </div>
                                                    <div className="flex h-10 items-center gap-4">
                                                        <Clock className="ml-2 h-4 w-4" />
                                                        Início
                                                    </div>
                                                </div>
                                            </div>
                                            <div className="px-4 pb-4">
                                                <div className="flex items-end gap-2">
                                                    <div className="grid gap-1 text-center">
                                                        <Label htmlFor="hours" className="text-xs">
                                                            Hours
                                                        </Label>
                                                        <TimePickerInput
                                                            picker="hours"
                                                            date={form.getValues('horaFinal') || new Date()}
                                                            setDate={(newDate) => {
                                                                const hour = newDate.getHours();
                                                                form.setValue('horaFinal', newDate);
                                                                setFinalHour(hour); // You can remove setTime since it's not used
                                                            }}
                                                            ref={finalHourRef}
                                                            onLeftFocus={() => finalHourRef.current?.focus()}
                                                            onChange={handleFinalHourChange}
                                                        />
                                                    </div>
                                                    <div className="grid gap-1 text-center">
                                                        <Label htmlFor="minutes" className="text-xs">
                                                            Minutes
                                                        </Label>
                                                        <TimePickerInput
                                                            picker="minutes"
                                                            date={form.getValues('minutoFinal') || new Date()}
                                                            setDate={(newDate) => {
                                                                const minute = newDate.getMinutes();
                                                                form.setValue('minutoFinal', newDate);
                                                                setFinalMinute(minute); // You can remove setTime since it's not used
                                                            }}
                                                            ref={finalMinuteRef}
                                                            onLeftFocus={() => finalMinuteRef.current?.focus()}
                                                            onChange={handleFinalMinuteChange}
                                                        />
                                                    </div>
                                                    <div className="flex h-10 items-center gap-4">
                                                        <Clock className="ml-2 h-4 w-4" />
                                                        Fim
                                                    </div>
                                                </div>
                                            </div>
                                        </PopoverContent>
                                    </Popover>
                                    <FormMessage />
                                </FormItem>
                            )}
                        />
                        <FormField
                            control={form.control}
                            name="descricao"
                            render={({ field }) => (
                                <FormItem>
                                    <FormLabel>Descrição</FormLabel>
                                    <FormControl>
                                        <Input placeholder="Ex.: Aula de DevOps" {...field} />
                                    </FormControl>
                                    <FormMessage />
                                </FormItem>
                            )}
                        />
                    </form>
                </Form>
                <DialogFooter className="sm:justify-end">
                    <DialogClose asChild>
                        <div className="flex gap-2">
                            <Button className="bg-black text-white hover:bg-gray-500" type="button" variant="secondary">
                                Close
                            </Button>
                            <Button onClick={handleButtonClick} className="bg-[#89A8B2] self-end text-white hover:bg-[#5A6C73] hover:text-white" type="submit">Enviar</Button>
                        </div>
                    </DialogClose>
                </DialogFooter>
            </DialogContent>
        </Dialog>
    )
}
