'use client'

import { useEffect, useState } from 'react';
import { usePathname, useRouter } from 'next/navigation';
import Image from 'next/image';
import BotaoNav from './BotaoNav';
import { CalendarFold, DoorOpen, FileUser, Users } from 'lucide-react';

export default function MenuLateral({ nome, email, foto }) {
  const [activeIndex, setActiveIndex] = useState(0);
  const pathname = usePathname();
  const router = useRouter();

  const navItems = [
    { texto: 'Reservas', icone: <CalendarFold size={28} />, router: '/' },
    { texto: 'Salas', icone: <DoorOpen size={28} />, router: '/salas' },
    { texto: 'Usuários', icone: <Users size={28} />, router: '/usuarios' },
    { texto: 'Perfil', icone: <FileUser size={28} />, router: '/perfil' },
  ];

  useEffect(() => {
    const activeItem = navItems.findIndex(item => item.router === pathname);
    setActiveIndex(activeItem); // Atualiza o botão ativo com base na rota
  }, [pathname]);

  return (
    <nav className="p-4 bg-primary h-screen w-[307px]">
      <div className="mb-6 flex gap-2 items-center">
        <Image
          src={foto}
          alt="foto de perfil"
          width={46}
          height={46}
          className="rounded-full border-2"
        />
        <div>
          <p className="leading-tight text-black font-bold">Olá {nome}</p>
          <p className="leading-tight text-black">{email}</p>
        </div>
      </div>

      <ul>
        {navItems.map((item, index) => (
          <li key={index}>
            <BotaoNav
              texto={item.texto}
              icone={item.icone}
              router={item.router}
              active={activeIndex === index}
              onClick={() => {
                setActiveIndex(index); // Atualiza o botão ativo ao clicar
                router.push(item.router);
              }}
            />
          </li>
        ))}
      </ul>
    </nav>
  );
}
